==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/bs.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Pohrana je nedostupna",
    "Storage invalid" : "Pohrana je neispravna",
    "Unknown error" : "Nepoznata greška",
    "Could not move %s - File with this name already exists" : "Nemoguće premjestiti %s - Datoteka takvog naziva već postoji",
    "Could not move %s" : "Nemoguće premjestiti %s",
    "Permission denied" : "Nemate ovlaštenje",
    "The target folder has been moved or deleted." : "Ciljni direktorij je premješten ili izbrisan.",
    "The name %s is already used in the folder %s. Please choose a different name." : "Naziv %s je već iskorišten u direktoriju %s. Molim odaberite drugi naziv.",
    "Error when creating the file" : "Greška pri kreiranju datoteke",
    "Error when creating the folder" : "Greška pri kreiranju direktorija",
    "Unable to set upload directory." : "Odredba direktorija učitavanja nije moguća.",
    "Invalid Token" : "Neispravan Znak",
    "No file was uploaded. Unknown error" : "Nijedna datoteka nije učitana. Nepoznata greška.",
    "There is no error, the file uploaded with success" : "Nema greške, datoteka je uspješno učitana.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Učitana datoteka prelazi maksimalnu dopuštenu veličinu datoteke upload_max_filesize navedenu u php. ini: ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Učitana datoteka premašuje maksimalnu dopuštenu veličinu datoteke MAX_FILE_SIZE navedenu u HTML formi",
    "The uploaded file was only partially uploaded" : "Učitana datoteka je samo djelomično učitana",
    "No file was uploaded" : "Nijedna datoteka nije učitana.",
    "Missing a temporary folder" : "Nedostaje privremeni direktorij.",
    "Failed to write to disk" : "Zapisivanje na disk nije uspjelo.",
    "Not enough storage available" : "Prostor za pohranu je nedovoljan",
    "Upload failed. Could not find uploaded file" : "Neuspješno učitavanje. Nije pronađena učitana dataoteka",
    "Upload failed. Could not get file info." : "Neuspješno učitavanje. Nedostupne informacije o datoteci.",
    "Invalid directory." : "Neispravan direktorij.",
    "Files" : "Datoteke",
    "All files" : "Sve datoteke",
    "Favorites" : "Favoriti",
    "Home" : "Kuća",
    "Close" : "Zatvori",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nemoguće učitati {filename} jer je ili direktorij ili ima 0 bajta",
    "Total file size {size1} exceeds upload limit {size2}" : "Ukupna veličina datoteke {size1} prelazi ograničenje unosa {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nedovoljno slobodnog prostora, vi učitavate {size1} a samo je {size2} preostalo",
    "Upload cancelled." : "Učitavanje je prekinuto.",
    "Could not get result from server." : "Nemoguće dobiti rezultat od servera.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Učitavanje datoteke je u toku. Napuštanje stranice prekinut će učitavanje.",
    "Actions" : "Radnje",
    "Download" : "Preuzmi",
    "Rename" : "Preimenuj",
    "Delete" : "Izbriši",
    "Select" : "Izaberi",
    "Pending" : "Na čekanju",
    "Unable to determine date" : "Nemoguće odrediti datum",
    "Error moving file." : "Greška pri premještanju datoteke",
    "Error moving file" : "Greška pri premještanju datoteke",
    "Error" : "Greška",
    "{new_name} already exists" : "{new_name} već postoji",
    "Could not rename file" : "Nemoguće preimenovati datoteku",
    "Could not create file" : "Datoteku nije moguće kreirati",
    "Could not create folder" : "Direktorij nije moguće kreirati",
    "Error deleting file." : "Greška pri brisanju datoteke",
    "Name" : "Ime",
    "Size" : "Veličina",
    "Modified" : "Izmijenjeno",
    "_%n folder_::_%n folders_" : ["direktorij","direktoriji","direktoriji"],
    "_%n file_::_%n files_" : ["%n datoteka","%n datoteke","%n datoteke"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "You don’t have permission to upload or create files here" : "Ovdje niste ovlašteni učitavati ili kreirati datoteke",
    "_Uploading %n file_::_Uploading %n files_" : ["Prenosim %n datoteku","Prenosim %n datoteke","Prenosim %n datoteke"],
    "New" : "Novo",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neispravno ime datoteke.",
    "File name cannot be empty." : "Naziv datoteke ne može biti prazan",
    "Your storage is full, files can not be updated or synced anymore!" : "Vaša pohrana je puna, datoteke više nije moguće ažurirati niti sinhronizirati!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Vaš prostor za pohranu je skoro pun ({usedSpacePercent}%)",
    "Favorited" : "Favorizovano",
    "Favorite" : "Favorit",
    "Upload" : "Učitaj",
    "Text file" : "Tekstualna datoteka",
    "Folder" : "Direktorij",
    "New folder" : "Novi direktorij",
    "%s could not be renamed as it has been deleted" : "%s nije moguće preimenovati jer je izbrisan",
    "%s could not be renamed" : "%s nije moguće preimenovati",
    "Upload (max. %s)" : "Učitaj (max. %s)",
    "File handling" : "Obrada datoteke",
    "Maximum upload size" : "Maksimalna veličina učitavanja",
    "max. possible: " : "max. moguće: ",
    "Save" : "Spasi",
    "Settings" : "Postavke",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Koristi slijedeću adresu za <a href=\"%s\" target=\"_blank\">pristup vašim datotekama putem WebDAV-a</a>",
    "Cancel upload" : "Prekini učitavanje",
    "Upload some content or sync with your devices!" : "Učitaj neki sadržaj ili sinhronizuj sa tvojim uređajima!",
    "Select all" : "Označi sve",
    "Upload too large" : "Učitavanje je preveliko",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke koje pokušavate učitati prelaze maksimalnu veličinu za učitavanje datoteka na ovom serveru.",
    "Files are being scanned, please wait." : "Datoteke se provjeravaju, molim pričekajte.",
    "Currently scanning" : "Provjera u toku",
    "No favorites" : "Nema favorita",
    "Files and folders you mark as favorite will show up here" : "Datoteke i direktorij koje ste označili kao favorite će biti prikazane ovdje"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/bs.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Pohrana je nedostupna",
    "Storage invalid" : "Pohrana je neispravna",
    "Unknown error" : "Nepoznata greška",
    "Unable to set upload directory." : "Odredba direktorija učitavanja nije moguća.",
    "Invalid Token" : "Neispravan Znak",
    "No file was uploaded. Unknown error" : "Nijedna datoteka nije učitana. Nepoznata greška.",
    "There is no error, the file uploaded with success" : "Nema greške, datoteka je uspješno učitana.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Učitana datoteka prelazi maksimalnu dopuštenu veličinu datoteke upload_max_filesize navedenu u php. ini: ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Učitana datoteka premašuje maksimalnu dopuštenu veličinu datoteke MAX_FILE_SIZE navedenu u HTML formi",
    "The uploaded file was only partially uploaded" : "Učitana datoteka je samo djelomično učitana",
    "No file was uploaded" : "Nijedna datoteka nije učitana.",
    "Missing a temporary folder" : "Nedostaje privremeni direktorij.",
    "Failed to write to disk" : "Zapisivanje na disk nije uspjelo.",
    "Not enough storage available" : "Prostor za pohranu je nedovoljan",
    "The target folder has been moved or deleted." : "Ciljni direktorij je premješten ili izbrisan.",
    "Upload failed. Could not find uploaded file" : "Neuspješno učitavanje. Nije pronađena učitana dataoteka",
    "Upload failed. Could not get file info." : "Neuspješno učitavanje. Nedostupne informacije o datoteci.",
    "Invalid directory." : "Neispravan direktorij.",
    "Files" : "Datoteke",
    "All files" : "Sve datoteke",
    "Favorites" : "Favoriti",
    "Home" : "Kuća",
    "Close" : "Zatvori",
    "Upload cancelled." : "Učitavanje je prekinuto.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nemoguće učitati {filename} jer je ili direktorij ili ima 0 bajta",
    "Total file size {size1} exceeds upload limit {size2}" : "Ukupna veličina datoteke {size1} prelazi ograničenje unosa {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nedovoljno slobodnog prostora, vi učitavate {size1} a samo je {size2} preostalo",
    "Could not get result from server." : "Nemoguće dobiti rezultat od servera.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Učitavanje datoteke je u toku. Napuštanje stranice prekinut će učitavanje.",
    "Actions" : "Radnje",
    "Download" : "Preuzmi",
    "Rename" : "Preimenuj",
    "Delete" : "Izbriši",
    "Disconnect storage" : "Diskonektuj pohranu",
    "Unshare" : "Prestani  dijeliti",
    "Select" : "Izaberi",
    "Pending" : "Na čekanju",
    "Unable to determine date" : "Nemoguće odrediti datum",
    "Name" : "Ime",
    "Size" : "Veličina",
    "Modified" : "Izmijenjeno",
    "_%n folder_::_%n folders_" : ["direktorij","direktoriji","direktoriji"],
    "_%n file_::_%n files_" : ["%n datoteka","%n datoteke","%n datoteke"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "You don’t have permission to upload or create files here" : "Ovdje niste ovlašteni učitavati ili kreirati datoteke",
    "_Uploading %n file_::_Uploading %n files_" : ["Prenosim %n datoteku","Prenosim %n datoteke","Prenosim %n datoteke"],
    "New" : "Novo",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neispravno ime datoteke.",
    "File name cannot be empty." : "Naziv datoteke ne može biti prazan",
    "Your storage is full, files can not be updated or synced anymore!" : "Vaša pohrana je puna, datoteke više nije moguće ažurirati niti sinhronizirati!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Vaš prostor za pohranu je skoro pun ({usedSpacePercent}%)",
    "Favorited" : "Favorizovano",
    "Favorite" : "Favorit",
    "Folder" : "Direktorij",
    "New folder" : "Novi direktorij",
    "Upload" : "Učitaj",
    "Upload (max. %s)" : "Učitaj (max. %s)",
    "File handling" : "Obrada datoteke",
    "Maximum upload size" : "Maksimalna veličina učitavanja",
    "max. possible: " : "max. moguće: ",
    "Save" : "Spasi",
    "Settings" : "Postavke",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Koristi slijedeću adresu za <a href=\"%s\" target=\"_blank\">pristup vašim datotekama putem WebDAV-a</a>",
    "Cancel upload" : "Prekini učitavanje",
    "Upload some content or sync with your devices!" : "Učitaj neki sadržaj ili sinhronizuj sa tvojim uređajima!",
    "Select all" : "Označi sve",
    "Upload too large" : "Učitavanje je preveliko",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke koje pokušavate učitati prelaze maksimalnu veličinu za učitavanje datoteka na ovom serveru.",
    "No favorites" : "Nema favorita",
    "Files and folders you mark as favorite will show up here" : "Datoteke i direktorij koje ste označili kao favorite će biti prikazane ovdje",
    "Text file" : "Tekstualna datoteka"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
